/*
  Loop Opener
    (C) あかつきみさき(みくちぃP)
    http://sunrisemoon.net/

  このスクリプトについて
    ラベルでグループとみなし作業するコンポの行き来に便利なスクリプト.
    アクティブなコンポジションと同じラベルで,プロジェクトパネル上で次に来るコンポジションを開きます.

  使用想定シチュエーション
    作業するコンポジションのラベル色を統一することで,作業コンポジションの変更をすばやく行えます.
    使用にはランチャーへの登録やスクリプトのショートカット登録がおすすめです.

  使用方法
    ファイル→スクリプト→スクリプトファイルを実行.

  動作環境
    Adobe After Effects CS6以上

  配布元
    http://sunrisemoon.net/

  バージョン情報
    2023/08/29 Ver 1.0.0 Release
*/

/// <reference path="D:\lib\aftereffects.d.ts\ae.d.ts"/>

(function () {
    var curComp = app.project.activeItem;
    var compList = [];

    for (var i = 1; i <= app.project.numItems; i++) {
        var curItem = app.project.item(i);
        if (!(curItem instanceof CompItem)) {
            continue;
        }

        // プロジェクトパネル上で選択していない,コンポ以外を選択しているときはプロジェクトパネル上で一番上のコンポを開くのでそれを取得
        if (!(curComp instanceof CompItem)) {
            curComp = curItem;
        }

        compList[compList.length] = curItem;
    }

    if (curComp == null) {
        return 0;
    }

    var loopCompList = [];
    for (var i = 0; i < compList.length; i++) {
        if (compList[i].label != curComp.label) {
            continue;
        }

        loopCompList[loopCompList.length] = compList[i];
    }

    ////////////////////////////////////////////////////////////////////////
    // whileに入るので保険
    var hasSameId = false;
    for (var i = 0; i < loopCompList.length; i++) {
        if (loopCompList[i].id == curComp.id) {
            hasSameId = true;
            break;
        }
    }

    if (!hasSameId) {
        alert("Not found target compsition.");
        return 0;
    }
    ////////////////////////////////////////////////////////////////////////

    while (loopCompList[0].id != curComp.id) {
        var shiftItem = loopCompList.shift();
        loopCompList[loopCompList.length] = shiftItem;
    }

    // コンポ選択時のみ次の対象を開く処理に入る
    // プロジェクトパネル上で選択していない,コンポ以外を選択しているときはプロジェクトパネル上で一番上のコンポが開かれる
    if (app.project.activeItem instanceof CompItem) {
        var shiftItem = loopCompList.shift();
        loopCompList[loopCompList.length] = shiftItem;
    }

    // タイムラインパネルがアクティブだと開かないことがあるため2回実行する
    loopCompList[0].openInViewer();
    loopCompList[0].openInViewer();

    clearOutput();
    writeLn("Open: " + loopCompList[0].name);

    return 0;
})();
